@@ -32,5 +32,5 @@ class DataLake:
         os.system(
             f"aws s3 sync s3://{self.bucket}/{self.key} ~/.ness/{self.key} "
             f"--exclude '*' --include '*{table or ''}.{self.format}*' "
-            f"--profile {self.profile}"
+            f"--profile {self.profile} --delete"
         )
